import type { VxeGridProps } from '#/adapter/vxe-table';
import type { DescItem } from '#/components/description';

import { getPopupContainer } from '@vben/utils';

import { Rate } from 'ant-design-vue';

import { type FormSchemaGetter } from '#/adapter/form';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'resCode',
    label: '维修单号'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'resDept',
    label: '维修部门'
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'resUser',
    label: '维修人'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '维修单号',
    field: 'resCode',
    minWidth: 160,
    fixed: 'left'
  },
  {
    title: '结果',
    field: 'fbResult',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'resId'
  },
  {
    component: 'Input',
    fieldName: 'resCode',
    componentProps: {
      readonly: true
    },
    label: '维修工单'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'fbResult',
    label: '结果反馈'
  },
  {
    component: 'Rate',
    fieldName: 'repairSatisfaction',
    label: '维修满意度'
  },
  {
    component: 'Rate',
    fieldName: 'repairTimeliness',
    label: '维修及时性'
  },
  {
    component: 'Rate',
    fieldName: 'serviceAttitude',
    label: '维修及态度'
  },
  {
    component: 'Rate',
    fieldName: 'repairSs',
    label: '维修现场6S'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'suggestions',
    label: '意见或建议'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'fbDept',
    label: '评价人部门',
    rules: 'selectRequired'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'fbUser',
    label: '评价人',
    rules: 'selectRequired'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'fbTime',
    label: '评价时间'
  }
];

export const descSchema: DescItem[] = [
  {
    field: 'resCode',
    label: '维修工单',
    labelMinWidth: 80
  },
  {
    field: 'fbResult',
    label: '结果反馈'
  },
  {
    field: 'repairSatisfaction',
    label: '维修满意度',
    render(value) {
      return (
        <div class="flex items-center">
          <Rate disabled value={Number(value)}></Rate>
        </div>
      );
    }
  },
  {
    field: 'repairTimeliness',
    label: '维修及时性',
    render(value) {
      return (
        <div class="flex items-center">
          <Rate disabled value={Number(value)}></Rate>
        </div>
      );
    }
  },
  {
    field: 'serviceAttitude',
    label: '维修及态度',
    render(value) {
      return (
        <div class="flex items-center">
          <Rate disabled value={Number(value)}></Rate>
        </div>
      );
    }
  },
  {
    field: 'repairSs',
    label: '维修现场6s',
    render(value) {
      return (
        <div class="flex items-center">
          <Rate disabled value={Number(value)}></Rate>
        </div>
      );
    }
  },
  {
    field: 'suggestions',
    label: '意见或建议'
  },
  {
    field: 'fbDeptName',
    label: '评价人部门'
  },
  {
    field: 'fbUserName',
    label: '评价人'
  },
  {
    field: 'fbTime',
    label: '评价时间'
  }
];
